PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/Topology.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
Topology.hpp
1#ifndef GYM_PCB_TOPOLOGY_H
2#define GYM_PCB_TOPOLOGY_H
3
4#include "Geometry.hpp"
5#include <string>
6#include <variant>
7#include <vector>
8
9class Net;
10
11 struct NetTopology
12{
13public:
14 std::vector<std::vector<std::variant<Point_25, std::string>>> Connections;
15 void create(Net&) const;
16};
17
18#endif // GYM_PCB_TOPOLOGY_H
Net
Definition Net.hpp:19
NetTopology
Definition Topology.hpp:12